pitchtools.CounterpointObject
=============================

.. inheritance-diagram:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.CounterpointObject.CounterpointObject.CounterpointObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
